import click
import requests
from PythonPSI.utils.data import HTTPS_OR_HTTP, RAW
from PythonPSI.utils.version import latest_version, current_version

version_info = "---  Current version: " + current_version() + "  ---  " + "Latest version: " + latest_version() + "  ---"

@click.command(help=version_info)
@click.option('--api_key', default='', help='Required to use the API in an automated way and make multiple requests per second')
@click.option('--category', default='performance', help='A Lighthouse category to run; if none are given, only Performance category will be run')
@click.option('--metrics', default='', help='Returns metrics of a particular field in response object')
@click.option('--locale', default='en', help='The locale used to localize formatted results')
@click.option('--stratergy', default='desktop', help='The analysis strategy (desktop or mobile) to use, and desktop is the default')
@click.option('--threshold', default='', help='Threshold score to pass the PageSpeed test. Useful for setting a performance budget.')
@click.option('--links', default='', help='If passed adds links with more info about opportunities. Useful for checking documentation about opportunities.')
@click.option('--utm_campaign', default='', help='Campaign name for analytics.')
@click.option('--utm_source', default='', help='Campaign source for analytics.')
@click.option('--captcha_token', default='', help='The captcha token passed when filling out a captcha.')
@click.argument('url')
def psi(api_key, category, metrics, locale, stratergy, threshold, links, utm_campaign, utm_source, captcha_token, url):
    if "https" in url:
        response = HTTPS_OR_HTTP()
        try:
            click.echo(response[metrics])
        except:
            click.echo(response)
    if "http" in url:
        response = HTTPS_OR_HTTP()
        try:
            click.echo(response[metrics])
        except:
            click.echo(response)
    else:
        response = RAW(url)
        try:
            click.echo(response[metrics])
        except:
            click.echo(response)


import json
import requests
import os.path
import PythonPSI
import importlib.resources as pkg_resources

URL = 'https://pypi.python.org/pypi/PythonPSI/json'

def latest_version():
    data = requests.get(URL).json()
    latest_version = data['info']['version']
    return(latest_version)

def current_version():
    VERSION = pkg_resources.read_text(PythonPSI, 'about.txt')
    return VERSION



import json
import requests
from PythonPSI.utils.data import HTTPS_OR_HTTP, RAW

def PSI(url, 
        api_key="", 
        metrics="", 
        category="performance", 
        locale="en", 
        stratergy="desktop", 
        threshold="", 
        links="", 
        utm_campaign="", 
        utm_source="", 
        captcha_token=""):
        
    if "https" in url:
        response = HTTPS_OR_HTTP(url, api_key, stratergy, locale, category, threshold, utm_campaign, utm_source, captcha_token)
        try:
            return(response[metrics])
        except:
            return(response)
    if "http" in url:
        response= HTTPS_OR_HTTP(url, api_key, stratergy, locale, category, threshold, utm_campaign, utm_source, captcha_token)
        try:
            return(response[metrics])
        except:
            return(response)
    else:
        response = RAW(url, api_key, stratergy, locale, category, threshold, utm_campaign, utm_source, captcha_token)
        try:
            return(response[metrics])
        except:
            return(response)


import requests
import json

QUERY_URL = 'https://www.googleapis.com/pagespeedonline/v5/runPagespeed?url='

def HTTPS_OR_HTTP(url, 
                api_key="", 
                stratergy="desktop", 
                locale="en", 
                category="performance", 
                threshold="", 
                utm_campaign="", 
                utm_source="", 
                captcha_token=""):

    raw_data = requests.get(QUERY_URL 
                            + url 
                            + '&key=' + api_key 
                            + '&stratergy=' + stratergy 
                            + '&locale=' + locale 
                            + '&category=' + category 
                            + '&threshold=' + threshold 
                            + '&links=' + links 
                            + '&utm_campaign=' + utm_campaign 
                            + '&utm_source=' + utm_source 
                            + '&captchaToken=' + captcha_token)
    data = raw_data.json()

    return(data)

def RAW(url, 
        api_key="", 
        stratergy="desktop", 
        locale="en", 
        category="performance", 
        threshold="", 
        utm_campaign="", 
        utm_source="", 
        captcha_token=""):

    site_url = "http://" + url
    raw_data = requests.get(QUERY_URL
                            + site_url 
                            + '&key=' + api_key 
                            + '&stratergy=' + stratergy 
                            + '&locale=' + locale 
                            + '&category=' + category 
                            + '&threshold=' + threshold 
                            + '&utm_campaign=' + utm_campaign 
                            + '&utm_source=' + utm_source 
                            + '&captchaToken=' + captcha_token)
    data = raw_data.json()

    return(data)


from setuptools import setup

with open('README.md') as f:
    README = f.read()

with open('PythonPSI/about.txt') as a:
    VERSION = a.read()

setup(
    name="PythonPSI",
    version=VERSION,
    packages=['PythonPSI', 'PythonPSI.utils'],
    description='CLI + API for Google PageSpeed Insights',
    long_description=README,
    long_description_content_type="text/markdown",
    package_data={'PythonPSI': ['about.txt']},
    include_package_data=True,
    url='https://github.com/prakhargurunani/PyPSI',
    download_url="https://github.com/prakhargurunani/PyPSI/archive/main.zip",
    author='Prakhar Gurunani',
    author_email='prakhargurunani@gmail.com',
    classifiers=[  # Optional
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 5 - Production/Stable',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate you support Python 3. These classifiers are *not*
        # checked by 'pip install'. See instead 'python_requires' below.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only',
    ],
    keywords='cli, google, python, seo, page-speed-insights, performance, google-apis',
    python_requires='>=3.5, <4',
    py_modules=['psi'],
    install_requires=[
        'click',
        'requests'
    ],
    entry_points='''
        [console_scripts]
        psi=PythonPSI.main:psi
    ''',
)